@@ -1,4 +1,4 @@
-# Copyright (C) 2023 Giovanni Fulco
+# Copyright (C) 2023,2024 Giovanni Fulco
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,3 +14,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 plugin_name : str = "subsonic"
+subsonic_plugin_release : str = "0.5.0"
+
+default_dump_streaming_properties : int = 0
